import { shortcut, store } from '@core/core';
import { ListItem } from './list_item/list_item';
import { ConnectionListModel } from './list.model';
import { getDatabaseType } from './list.service';
import { Tab } from '@fui/core';

@shortcut()
@store(ConnectionListModel)
export class ConnectionList extends BI.Pane {
    static xtype = 'dec.dcm.connection.list';

    store: ConnectionListModel['store'];
    model: ConnectionListModel['model'];

    groupWidget: any;
    tab: Tab;

    beforeRender(cb: Function) {
        this.store.setConnections().then(() => {
            cb();
        });
    }

    watch = {
        connections: () => {
            const times = this.groupWidget.times;
            this.groupWidget.populate(this.renderList(0, this.groupWidget.times * 50));
            this.groupWidget.times = times;
        },
        shwoType: (type: 'list' | 'none') => {
            this.tab.setSelect(type);
        },
    }

    render() {
        return {
            type: BI.Tab.xtype,
            single: true,
            showIndex: this.model.shwoType,
            ref: (_ref: Tab) => {
                this.tab = _ref;
            },
            cardCreator: (index: 'list' | 'none') => {
                if (index === 'none') {
                    return {
                        type: BI.CenterAdaptLayout.xtype,
                        items: [
                            {
                                type: BI.VTapeLayout.xtype,
                                width: 260,
                                height: 150,
                                items: [
                                    {
                                        el: {
                                            type: BI.Layout.xtype,
                                            cls: 'data-connection-background',
                                        },
                                        height: 130,
                                    },
                                    {
                                        type: BI.Label.xtype,
                                        cls: 'bi-tips',
                                        text: BI.i18nText('Dec-Dcm_Connection_None'),
                                    },
                                ],
                            },
                        ],
                    };
                }

                return {
                    type: BI.Loader.xtype,
                    itemsCreator: (options: {times: number}, populate) => {
                        populate(this.renderList((options.times - 1) * 50, options.times * 50));
                    },
                    hasNext: options => options.times * 50 < BI.size(this.model.connections),
                    ref: (_ref: any) => {
                        this.groupWidget = _ref;
                    },
                };
            },
        };
    }

    private renderList(start = 0, end = 0) {
        return this.model.connections.slice(start, end).map((item, index) => {
            return {
                type: ListItem.xtype,
                name: item.connectionName,
                value: item.connectionName,
                creator: item.creator,
                databaseType: getDatabaseType(item),
                selected: this.model.connectionSelected ? this.model.connectionSelected === item.connectionName : index === 0,
            };
        });
    }
}
