import { model, Model } from '@core/core';
import { AppModel } from '../../../../app.model';
import { ApiFactory } from '../../../../crud/apiFactory';
import { ResultType } from '../../../../crud/crud.typings';
import { getChartLength } from '../../../../app.service';
import { NAME_MAX_LENGTH } from '../../../../app.constant';
import { PAGE_INDEX } from '@constants/constant';

const api = new ApiFactory().create();

@model()
export class ListItemModel extends Model<{
    types: {
        connectionSelected: AppModel['TYPE']['connectionSelected'];
        connectionSelectedOne: AppModel['TYPE']['connectionSelectedOne'];
        datebaseTypeSelectedOne: AppModel['TYPE']['datebaseTypeSelectedOne'];
        connections: AppModel['TYPE']['connections'];
        pageIndex: AppModel['TYPE']['pageIndex'];
        datebaseTypeSelected: AppModel['TYPE']['datebaseTypeSelected'];
        isCopy: AppModel['TYPE']['isCopy']
    },
    context: ListItemModel['context'];
}> {
    static xtype = 'dec.dcm.model.connection.list_item';

    context = <const>['connectionSelected', 'connections', 'pageIndex', 'datebaseTypeSelectedOne', 'connectionSelectedOne', 'datebaseTypeSelected', 'isCopy', 'connectionLicInfo'];

    state() {
        return {
            isEdit: false,
        };
    }

    actions = {
        setConnectionSelected: (name: string) => {
            this.model.connectionSelected = name;
        },
        deleteConnection: (name: string) => {
            api.getConnectionStatus(name).then(re => {
                this.removeConnection(name);
            })
                .catch(() => {

                });
        },
        setPageIndex: (pageIndex: string) => {
            this.model.pageIndex = pageIndex;
        },

        testConnection: (name: string) => api.testConnection(this.model.connections.find(item => item.connectionName === name)),
        getConnectionStatus: () => api.getConnectionStatus(this.model.connectionSelected),
        setDatebaseTypeSelected: (name: string) => {
            this.model.datebaseTypeSelected = name;
        },
        setIsEdit: (isEdit: boolean, name: string) => {
            if (isEdit) {
                api.getConnectionStatus(name)
                    .then(re => {
                        this.model.isEdit = true;
                    })
                    .catch(() => {
                    });
            } else {
                api.shutdownConnectionStatus(name);
                this.model.isEdit = false;
            }
        },
        changeName: (oldName: string, newName: string): Promise<ResultType> => {
            if (!newName) {
                return new Promise(resolve => {
                    resolve({ errorCode: '1', errorMsg: 'Dec-Dcm_Connection_ConnectionName_Cannt_Null' });
                });
            }
            if (getChartLength(newName) > NAME_MAX_LENGTH) {
                return new Promise(resolve => {
                    resolve({
                        errorCode: '1',
                        errorMsg: BI.i18nText('Dec-Dcm_Connection_Cannot_Too_Lang', NAME_MAX_LENGTH),
                    });
                });
            }
            const hasNamed = this.model.connections.some(item => item.connectionName === newName);
            if (hasNamed && oldName !== newName) {
                return new Promise(resolve => {
                    resolve({ errorCode: '1', errorMsg: 'Dec-Dcm_Connection_Is_Existence' });
                });
            }
            const connection = BI.clone(this.model.connections.find(item => item.connectionName === oldName));
            connection.connectionId = oldName;
            connection.connectionName = newName;


            return api.updateConnection(connection)
                .then(re => {
                    if (!re.errorCode) {
                        this.model.connections = this.model.connections.map(item => {
                            return {
                                ...item,
                                connectionName: item.connectionName === oldName ? newName : item.connectionName,
                                connectionId: item.connectionName === oldName ? newName : item.connectionName,
                            };
                        });
                        if (this.model.connectionSelected === oldName) {
                            this.model.connectionSelected = newName;
                        }
                    }

                    return re;
                });
        },
        copyConnection(connectionName) {
            if (this.model.connectionLicInfo.currentConnectionNum >= this.model.connectionLicInfo.maxConnectionNum) {
                BI.Services.getService('dec.service.component.icon_text.msg').alert({
                    text: BI.i18nText('Dec-Connection_Lic_Limit_Approach_Prevent_Tip', this.model.connectionLicInfo.maxConnectionNum),
                });

                return;
            }
            this.setConnectionSelected(connectionName);
            this.setIsCopy(true);
            this.setPageIndex(PAGE_INDEX.MAINTAIN);
        },
        setIsCopy: (isCopy: boolean) => {
            this.model.isCopy = isCopy;
        },
        isDriverError: (errorCode: string) => api.isDriverError(errorCode),
    };

    removeConnection(name: string) {
        api.deleteConnection(name)
            .then(re => {
                this.model.connectionLicInfo.currentConnectionNum -= 1;

                return api.getConnectionList();
            })
            .then(connections => {
                this.model.connections = connections.data;
                this.model.connections.forEach(item => {
                    // 后端传过来的是字符串，转为对象
                    item.connectionData = JSON.parse(item.connectionData as string);
                });
                if (name === this.model.connectionSelected) {
                    this.model.connectionSelected = BI.size(this.model.connections) > 0 ? this.model.connections[0].connectionName : '';
                }
                api.shutdownConnectionStatus(name);
            });
    }
}
