import { shortcut, store } from '@core/core';
import { PoolModel } from './pool.model';
import './pool.less';
import { ConnectionPoolType } from '../../../crud/crud.typings';
import { Label } from '@fui/core';

@shortcut()
@store(PoolModel)
export class Pool extends BI.Widget {
    static xtype = 'dec.dcm.connection_pool.pool';

    props = {
        baseCls: 'dec-dcm-connection-pool',
        $testId: 'dec-dcm-connection-pool',
    }
    model: PoolModel['model'];

    maxActive: Label;
    maxIdle: Label;
    numActive: Label;
    numIdle: Label;

    watch = {
        pool: (pool: ConnectionPoolType) => {
            this.maxActive.setText(`${pool.maxActive}`);
            this.maxIdle.setText(`${pool.maxIdle}`);
            this.numActive.setText(`${pool.numActive}`);
            this.numIdle.setText(`${pool.numIdle}`);
        },
    }

    render() {
        return {
            type: BI.VerticalLayout.xtype,
            items: [
                {
                    type: BI.FloatCenterLayout.xtype,
                    hgap: 20,
                    vgap: 10,
                    height: 200,
                    items: [
                        {
                            el: {
                                type: BI.CenterAdaptLayout.xtype,
                                cls: 'bi-background',
                                items: [
                                    {
                                        type: BI.VerticalLayout.xtype,
                                        cls: 'right-status-board-item',
                                        items: [
                                            {
                                                type: BI.CenterAdaptLayout.xtype,
                                                items: [
                                                    {
                                                        type: BI.VerticalAdaptLayout.xtype,
                                                        items: [
                                                            {
                                                                type: BI.Label.xtype,
                                                                $testId: 'dec-dcm-pool-status-number',
                                                                $value: 'active',
                                                                cls: 'bi-high-light card-font-heighlight',
                                                                ref: (_ref: Label) => {
                                                                    this.numActive = _ref;
                                                                },
                                                            },
                                                            {
                                                                type: BI.Label.xtype,
                                                                text: '/',
                                                            },
                                                            {
                                                                type: BI.Label.xtype,
                                                                $testId: 'dec-dcm-pool-status-max',
                                                                $value: 'active',
                                                                ref: (_ref: Label) => {
                                                                    this.maxActive = _ref;
                                                                },
                                                            },
                                                        ],
                                                    },
                                                ],
                                            },
                                            {
                                                type: BI.Label.xtype,
                                                text: BI.i18nText('Dec-Dcm_Active_Connections_Number'),
                                            },
                                        ],
                                    },
                                ],
                            },
                        },
                        {
                            type: BI.CenterAdaptLayout.xtype,
                            cls: 'bi-background',
                            items: [
                                {
                                    type: BI.VerticalLayout.xtype,
                                    cls: 'right-status-board-item',
                                    items: [
                                        {
                                            type: BI.CenterAdaptLayout.xtype,
                                            items: [
                                                {
                                                    type: BI.VerticalAdaptLayout.xtype,
                                                    items: [
                                                        {
                                                            type: BI.Label.xtype,
                                                            $testId: 'dec-dcm-pool-status-number',
                                                            $value: 'idle',
                                                            cls: 'bi-high-light card-font-heighlight',
                                                            ref: (_ref: Label) => {
                                                                this.numIdle = _ref;
                                                            },
                                                        },
                                                        {
                                                            type: BI.Label.xtype,
                                                            text: '/',
                                                        },
                                                        {
                                                            type: BI.Label.xtype,
                                                            $testId: 'dec-dcm-pool-status-max',
                                                            $value: 'idle',
                                                            ref: (_ref: Label) => {
                                                                this.maxIdle = _ref;
                                                            },
                                                        },
                                                    ],
                                                },
                                            ],
                                        },
                                        {
                                            type: BI.Label.xtype,
                                            text: BI.i18nText('Dec-Dcm_Leisure_Connections_Number'),
                                        },
                                    ],
                                },
                            ],
                        },
                    ],
                },
            ],
        };
    }
}
