import { shortcut, store } from '@core/core';
import { DatebaseTypeModel } from './database_type.model';
import { ImgPrefix, PluginImgPrefix } from '@constants/env';
import './database_type.less';
import { PAGE_INDEX } from '@constants/constant';
import { Img } from '@fui/core';

@shortcut()
@store(DatebaseTypeModel)
export class DatebaseType extends BI.BasicButton {
    static xtype = 'dec.dcm.datebase.type';

    props = {
        text: '',
        url: '',
        value: '',
        height: 130,
        width: 130,
        keyword: '',
        databaseType: '',
        iconUrl: '',
        baseCls: 'dec-dcm-database-type',
        $testId: 'dec-dcm-database-type',
    }

    img: Img;

    store: DatebaseTypeModel['store'];

    render() {
        const { text, keyword, databaseType, iconUrl } = this.options;
        
        return {
            type: BI.AbsoluteLayout.xtype,
            items: [
                {
                    el: {
                        type: BI.VTapeLayout.xtype,
                        cls: 'bi-list-item-active bi-border',
                        items: [
                            {
                                el: {
                                    type: BI.Img.xtype,
                                    src: iconUrl ? this.getIconUrl(iconUrl) : `${ImgPrefix}${databaseType}.jpg`,
                                    ref: (_ref: Img) => {
                                        this.img = _ref;
                                    },
                                },
                                height: 90,
                            },
                            {
                                type: BI.Label.xtype,
                                cls: 'bi-header-background',
                                text,
                                title: text,
                                keyword,
                            },
                        ],
                        top: 5,
                        left: 5,
                        right: 5,
                        bottom: 5,
                    },
                },
            ],
        };
    }

    doClick() {
        const { value } = this.options;
        this.store.setDatebaseTypeSelected(value);
        this.store.setPageIndex(PAGE_INDEX.MAINTAIN);
    }

    mounted() {
        this.setDefaultImg();
    }

    private setDefaultImg() {
        const ImgObj = new Image();
        ImgObj.src = this.img.getSrc();
        ImgObj.onerror = () => {
            this.img.setSrc(`${ImgPrefix}default.jpg`);
        };
    }

    private getIconUrl(url: string) {
        if (url.startsWith('/')) {
            return `${PluginImgPrefix}${url}`;
        }
        
        return `${PluginImgPrefix}/${url}`;
    }
}
