import {shortcut} from '@core/core';
import {FormItem} from '../../components/form_item/form_item';
import {ConnectionJNDI, Connection, ContextHashtable} from 'src/modules/crud/crud.typings';
import {CONNECT_CHARSET, CONNECTION_LAYOUT, JNDI_FACTORYS} from '@constants/constant';
import {Collapse, EVENT_CHANGE} from 'src/modules/components/collapse/collapse';
import {connectionType} from '@constants/env';
import {TextChecker} from '../../../../components/text_checker/text_checker';
import {EditorIconCheckCombo, TextEditor, TextValueCombo, VerticalLayout} from '@fui/core';

@shortcut()
export class FormJndi extends BI.Widget {
    static xtype = 'dec.dcm.maintain.form.jndi';

    props = {
        formData: {} as Connection,
    }
    advancedSet: VerticalLayout;
    form = {
        connectionName: null,
        jndiName: null,
        initial: null,
        providerUrl: null,
        securityPrincipal: null,
        securityCredentials: null,
        newCharsetName: null,
        factoryObject: null,
        factoryState: null,
        factoryUrlPkgs: null,
        dnsUrl: null,
        authoritative: null,
        batchsize: null,
        referral: null,
        securityProtocol: null,
        authentication: null,
        language: null,
        applet: null,
    }

    render() {
        const {connectionName, connectionData} = this.options.formData;
        const {jndiName, newCharsetName, contextHashtable} = connectionData as ConnectionJNDI;
        const {hgap, vgap} = CONNECTION_LAYOUT;

        return {
            type: BI.VerticalLayout.xtype,
            hgap,
            vgap,
            items: [
                {
                    type: FormItem.xtype,
                    name: BI.i18nText('Dec-Dcm_Connection_Name'),
                    nameWidth: 200,
                    forms: [{
                        type: TextChecker.xtype,
                        $value: 'connection-name',
                        width: 300,
                        value: connectionName,
                        ref: (_ref: TextChecker) => {
                            this.form.connectionName = _ref;
                        },
                    }],
                },
                {
                    type: FormItem.xtype,
                    name: BI.i18nText('Dec-Dcm_Connection_JNDI_Form_ConnectionName'),
                    nameWidth: 200,
                    forms: [{
                        type: BI.TextEditor.xtype,
                        $value: 'jdni-name',
                        width: 300,
                        allowBlank: true,
                        value: jndiName,
                        ref: (_ref: TextEditor) => {
                            this.form.jndiName = _ref;
                        },
                    }],
                },
                {
                    type: BI.HTapeLayout.xtype,
                    height: 175,
                    items: [
                        {
                            el: {
                                type: BI.FloatLeftLayout.xtype,
                                items: [
                                    {
                                        type: BI.Label.xtype,
                                        cls: 'bi-font-bold',
                                        textAlign: 'left',
                                        text: BI.i18nText('Dec-Dcm_Connection_JNDI_Form_Connection'),
                                    },
                                ],
                            },
                            width: 200,
                        },
                        {
                            type: BI.VerticalLayout.xtype,
                            bgap: 15,
                            height: 175,
                            items: [
                                {
                                    type: FormItem.xtype,
                                    name: 'INTIAL_CONTEXT_FACTORY',
                                    nameWidth: 200,
                                    isBold: false,
                                    forms: [{
                                        type: BI.EditorIconCheckCombo.xtype,
                                        $testId: 'dec-editor-icon-check-combo',
                                        $value: 'initial',
                                        width: 300,
                                        value: contextHashtable['java.naming.factory.initial'],
                                        ref: (_ref: EditorIconCheckCombo) => {
                                            this.form.initial = _ref;
                                        },
                                        items: JNDI_FACTORYS.map(item => {
                                            return {
                                                text: item.factory,
                                                value: item.factory,
                                            };
                                        }),
                                        listeners: [{
                                            eventName: BI.EditorIconCheckCombo.EVENT_CHANGE,
                                            action: () => {
                                                const value = this.form.initial.getValue();
                                                const factory = JNDI_FACTORYS.find(item => item.factory === value);
                                                factory ? this.form.providerUrl.setValue(factory.url) : null;
                                            },
                                        }],
                                    }],
                                },
                                {
                                    type: FormItem.xtype,
                                    name: 'PROVIDER_URL',
                                    isBold: false,
                                    nameWidth: 200,
                                    forms: [{
                                        type: BI.TextEditor.xtype,
                                        $value: 'provider-url',
                                        width: 300,
                                        allowBlank: true,
                                        value: contextHashtable['java.naming.provider.url'],
                                        ref: (_ref: TextEditor) => {
                                            this.form.providerUrl = _ref;
                                        },
                                    }],
                                },
                                {
                                    type: FormItem.xtype,
                                    name: 'SECURITY_PRINCIPAL',
                                    isBold: false,
                                    nameWidth: 200,
                                    forms: [{
                                        type: BI.TextEditor.xtype,
                                        $value: 'security-principal',
                                        width: 300,
                                        allowBlank: true,
                                        value: contextHashtable['java.naming.security.principal'],
                                        ref: (_ref: TextEditor) => {
                                            this.form.securityPrincipal = _ref;
                                        },
                                    }],
                                },
                                {
                                    type: FormItem.xtype,
                                    name: 'SECURITY_CREDENTIALS',
                                    isBold: false,
                                    nameWidth: 200,
                                    forms: [{
                                        type: BI.TextEditor.xtype,
                                        $value: 'security-credentials',
                                        width: 300,
                                        allowBlank: true,
                                        value: contextHashtable['java.naming.security.credentials'],
                                        ref: (_ref: TextEditor) => {
                                            this.form.securityCredentials = _ref;
                                        },
                                    }],
                                },
                                {
                                    type: BI.Label.xtype,
                                    bgap: -15,
                                    cls: 'bi-tips',
                                    textAlign: 'left',
                                    text: BI.i18nText('Dec-Dcm_Connection_JNDI_Warning'),
                                },
                            ],
                        },
                    ],
                },
                {
                    type: FormItem.xtype,
                    name: BI.i18nText('Dec-Dcm_Connection_Form_OriginalCharsetName'),
                    nameWidth: 200,
                    forms: [{
                        type: BI.TextValueCombo.xtype,
                        $value: 'original-charset-name',
                        width: 300,
                        value: newCharsetName ? newCharsetName : '',
                        items: CONNECT_CHARSET,
                        ref: (_ref: TextValueCombo) => {
                            this.form.newCharsetName = _ref;
                        },
                    }],
                },
                {
                    type: Collapse.xtype,
                    width: 70,
                    name: BI.i18nText('Dec-Dcm_Connection_Form_Database_Advanced_Setting'),
                    listeners: [
                        {
                            eventName: EVENT_CHANGE,
                            action: (isCollapse: boolean) => {
                                this.advancedSet.setVisible(!isCollapse);
                            },
                        },
                    ],
                },
                {
                    type: BI.VerticalLayout.xtype,
                    vgap,
                    tgap: -15,
                    invisible: true,
                    ref: (_ref: VerticalLayout) => {
                        this.advancedSet = _ref;
                    },
                    items: [
                        {
                            type: FormItem.xtype,
                            name: 'OBJECT_FACTORIES',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'factory-object',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.factory.object'],
                                ref: (_ref: TextEditor) => {
                                    this.form.factoryObject = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'STATE_FACTORIES',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'factory-state',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.factory.state'],
                                ref: (_ref: TextEditor) => {
                                    this.form.factoryState = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'URL_PKG_PREFIXES',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'factory-url-pkgs',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.factory.url.pkgs'],
                                ref: (_ref: TextEditor) => {
                                    this.form.factoryUrlPkgs = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'DNS_URL',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'dns-url',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.dns.url'],
                                ref: (_ref: TextEditor) => {
                                    this.form.dnsUrl = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'AUTHORITATIVE',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'authoritative',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.authoritative'],
                                ref: (_ref: TextEditor) => {
                                    this.form.authoritative = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'BATCHSIZE',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'batchsize',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.batchsize'],
                                ref: (_ref: TextEditor) => {
                                    this.form.batchsize = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'REFERRAL',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'referral',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.referral'],
                                ref: (_ref: TextEditor) => {
                                    this.form.referral = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'SECURITY_PROTOCOL',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'security-protocol',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.security.protocol'],
                                ref: (_ref: TextEditor) => {
                                    this.form.securityProtocol = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'SECURITY_AUTHENTICATION',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'security-authentication',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.security.authentication'],
                                ref: (_ref: TextEditor) => {
                                    this.form.authentication = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'LANGUAGE',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'language',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.language'],
                                ref: (_ref: TextEditor) => {
                                    this.form.language = _ref;
                                },
                            }],
                        },
                        {
                            type: FormItem.xtype,
                            name: 'APPLET',
                            nameWidth: 200,
                            forms: [{
                                type: BI.TextEditor.xtype,
                                $value: 'applet',
                                width: 300,
                                allowBlank: true,
                                value: contextHashtable['java.naming.applet'],
                                ref: (_ref: TextEditor) => {
                                    this.form.applet = _ref;
                                },
                            }],
                        },
                    ],
                },
            ],
        };
    }

    public setError(value: string) {
        this.form.connectionName.setError(value);
    }

    public getSubmitValue(): Connection {
        const connectionData = this.options.formData.connectionData as ConnectionJNDI;

        const contextHashtable = {
            'java.naming.factory.initial': this.form.initial.getValue(),
            'java.naming.provider.url': this.form.providerUrl.getValue(),
            'java.naming.factory.object': this.form.factoryObject.getValue(),
            'java.naming.factory.state': this.form.factoryState.getValue(),
            'java.naming.factory.url.pkgs': this.form.factoryUrlPkgs.getValue(),
            'java.naming.dns.url': this.form.dnsUrl.getValue(),
            'java.naming.authoritative': this.form.authoritative.getValue(),
            'java.naming.batchsize': this.form.batchsize.getValue(),
            'java.naming.referral': this.form.referral.getValue(),
            'java.naming.security.protocol': this.form.securityProtocol.getValue(),
            'java.naming.security.authentication': this.form.authentication.getValue(),
            'java.naming.security.principal': this.form.securityPrincipal.getValue(),
            'java.naming.security.credentials': this.form.securityCredentials.getValue(),
            'java.naming.language': this.form.language.getValue(),
            'java.naming.applet': this.form.applet.getValue(),
        };

        for (const propName in contextHashtable) {
            if (contextHashtable[propName] === null || contextHashtable[propName] === undefined || contextHashtable[propName] === '') {
                delete contextHashtable[propName];
            }
        }

        return {
            connectionId: this.form.connectionName.getValue(),
            connectionName: this.form.connectionName.getValue(),
            connectionType: connectionType.JNDI,
            connectionData: <ConnectionJNDI>BI.extend({}, connectionData, {
                jndiName: this.form.jndiName.getValue(),
                newCharsetName: this.form.newCharsetName.getValue()[0] || '',
                originalCharsetName: this.form.newCharsetName.getValue()[0] || '',
                creator: Dec ? Dec.personal.username : '',
                contextHashtable: contextHashtable as ContextHashtable,
            }),
        };
    }
}
